pub struct CondensedGraph {
pub components: Vec<Vec<NodeId>>,
pub edges: Vec<Vec<usize>>,
}Expand description
The result of condensing a directed graph into its SCC DAG.
Each node in the condensed graph represents one SCC of the original graph. The condensed graph is always a DAG (directed acyclic graph).
Fields
components: Vec<Vec<NodeId>>components[i] is the list of original NodeIds that belong to
super-node i in the condensed graph.
edges: Vec<Vec<usize>>Edges of the condensed DAG.
edges[i] is the list of super-node indices that super-node i has
a directed edge to. Self-loops (SCC to itself) are not included.
Implementations
Sourceimpl CondensedGraph
impl CondensedGraph
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Returns the number of super-nodes (SCCs) in the condensed graph.